Module buffer

Structs

BinaryBuffer
A compact buffer for storing binary coloured display data.
RotatedBuffer
Enables arbitrarily rotating an underlying DrawTarget buffer. This is useful if the default display orientation does not match the desired orientation of the content.

Enums

Rotate
Represents a 90, 180, or 270 degree clockwise rotation of a point within a given size.

Traits

Rotation

Functions

binary_buffer_length
Computes the correct size for the binary buffer based on the given dimensions.