pub struct BinaryBuffer<const L: usize> { /* private fields */ }Expand description
A compact buffer for storing binary coloured display data.
This buffer packs the data such that each byte represents 8 pixels.
Implementations
Sourceimpl<const L: usize> BinaryBuffer<L>
impl<const L: usize> BinaryBuffer<L>
Sourcepub fn new(dimensions: Size) -> Self
pub fn new(dimensions: Size) -> Self
Creates a new BinaryBuffer with all pixels set to BinaryColor::Off.
The dimensions must match the buffer length L, and the width must be a multiple of 8.
use embedded_graphics::prelude::Size;
use epd_waveshare_async::buffer::{binary_buffer_length, BinaryBuffer};
const DIMENSIONS: Size = Size::new(8, 8);
let buffer = BinaryBuffer::<{binary_buffer_length(DIMENSIONS)}>::new(DIMENSIONS);Trait Implementations
Sourceimpl<const L: usize> Dimensions for BinaryBuffer<L>
impl<const L: usize> Dimensions for BinaryBuffer<L>
Sourcefn bounding_box(&self) -> Rectangle
fn bounding_box(&self) -> Rectangle
Returns the bounding box.
Sourceimpl<const L: usize> DrawTarget for BinaryBuffer<L>
impl<const L: usize> DrawTarget for BinaryBuffer<L>
Sourcetype Color = BinaryColor
type Color = BinaryColor
The pixel color type the targetted display supports.
Sourcetype Error = Infallible
type Error = Infallible
Error type to return when a drawing operation fails. Read more
Sourcefn draw_iter<I>(&mut self, pixels: I) -> Result<(), Self::Error>
fn draw_iter<I>(&mut self, pixels: I) -> Result<(), Self::Error>
Draw individual pixels to the display without a defined order. Read more
Sourcefn fill_contiguous<I>(
&mut self,
area: &Rectangle,
colors: I,
) -> Result<(), Self::Error>where
I: IntoIterator<Item = Self::Color>,
fn fill_contiguous<I>(
&mut self,
area: &Rectangle,
colors: I,
) -> Result<(), Self::Error>where
I: IntoIterator<Item = Self::Color>,
Fill a given area with an iterator providing a contiguous stream of pixel colors. Read more