Epd2In9

Struct Epd2In9 

pub struct Epd2In9<HW, STATE> { /* private fields */ }
Controls v1 of the 2.9“ Waveshare e-paper display.

The display has a portrait orientation. This uses BinaryColor, where Off is black and On is white.

HW should implement ResetHw, BusyHw, DcHw, SpiHw, DelayHw, and ErrorHw.

Implementations

Source

impl<HW> Epd2In9<HW, StateUninitialized>
where HW: DcHw + ResetHw + BusyHw + DelayHw + ErrorHw + SpiHw, HW::Error: From<<HW::Dc as ErrorType>::Error> + From<<HW::Reset as ErrorType>::Error> + From<<HW::Busy as ErrorType>::Error> + From<<HW::Spi as ErrorType>::Error>,

pub fn new(hw: HW) -> Self

Source

impl<HW, STATE> Epd2In9<HW, STATE>
where HW: DcHw + ResetHw + BusyHw + DelayHw + ErrorHw + SpiHw, STATE: StateAwake, HW::Error: From<<HW::Dc as ErrorType>::Error> + From<<HW::Reset as ErrorType>::Error> + From<<HW::Busy as ErrorType>::Error> + From<<HW::Spi as ErrorType>::Error>,

pub async fn init( self, spi: &mut HW::Spi, mode: RefreshMode, ) -> Result<Epd2In9<HW, StateReady>, HW::Error>

Initialise the display. This should be called before any other operations.

Source

impl<HW, STATE> Epd2In9<HW, STATE>
where HW: DcHw + BusyHw + ErrorHw + SpiHw, STATE: StateAwake, HW::Error: From<<HW::Dc as ErrorType>::Error> + From<<HW::Busy as ErrorType>::Error> + From<<HW::Spi as ErrorType>::Error>,

pub async fn set_border( &mut self, spi: &mut HW::Spi, color: BinaryColor, ) -> Result<(), HW::Error>

Sets the border to the specified colour. You need to call Displayable::update_display using RefreshMode::Full afterwards to apply this change.

Note: on my board, the white setting fades to grey fairly quickly. I have not found a way to avoid this.

pub async fn send( &mut self, spi: &mut HW::Spi, command: Command, data: &[u8], ) -> Result<(), HW::Error>

Send the following command and data to the display. Waits until the display is no longer busy before sending.

Source

impl<HW> Epd2In9<HW, StateReady>
where HW: DcHw + BusyHw + DelayHw + ErrorHw + SpiHw, HW::Error: From<<HW::Dc as ErrorType>::Error> + From<<HW::Busy as ErrorType>::Error> + From<<HW::Spi as ErrorType>::Error>,

pub async fn set_refresh_mode( &mut self, spi: &mut HW::Spi, mode: RefreshMode, ) -> Result<(), HW::Error>

Sets the refresh mode.

pub async fn set_window( &mut self, spi: &mut HW::Spi, shape: Rectangle, ) -> Result<(), HW::Error>

Sets the window to which the next image data will be written.

The x-axis only supports multiples of 8; values outside this result in a debug-mode panic, or potentially misaligned content when debug assertions are disabled.

pub async fn set_cursor( &mut self, spi: &mut HW::Spi, position: Point, ) -> Result<(), HW::Error>

Sets the cursor position to write the next data to.

The x-axis only supports multiples of 8; values outside this will result in a panic in debug mode, or potentially misaligned content if debug assertions are disabled.