pub enum Bypass {
Normal = 0,
AllZero = 4,
Inverted = 8,
}Variants
Normal = 0
Remove any RAM bypass setting.
AllZero = 4
Reads all zeros as the base for the partial diff.
Inverted = 8
Reads the base of the partial diff as if it’s inverted.