pub fn new_binary_buffer() -> Epd2In9BinaryBufferExpand description
Constructs a new binary buffer for use with the Epd2In9V2 display.
pub fn new_binary_buffer() -> Epd2In9BinaryBufferConstructs a new binary buffer for use with the Epd2In9V2 display.