pub const fn new_binary_buffer() -> Epd7In5BinaryBufferExpand description
Constructs a new binary buffer for use with the [Epd7in5] display.
pub const fn new_binary_buffer() -> Epd7In5BinaryBufferConstructs a new binary buffer for use with the [Epd7in5] display.