Module buffer

Structs

BinaryBuffer
A compact buffer for storing binary coloured display data.

Functions

binary_buffer_length
Computes the correct size for the binary buffer based on the given dimensions.