epd_
waveshare_
async
0.1.0-alpha
Module buffer
Module Items
Structs
Functions
In crate epd_
waveshare_
async
epd_waveshare_async
Module
buffer
Structs

Binary
Buffer
A compact buffer for storing binary coloured display data.
Functions

binary_
buffer_
length
Computes the correct size for the binary buffer based on the given dimensions.