pub enum Error {
Uninitialized,
Sleeping,
WrongRefreshMode,
}Expand description
Indicates usage errors due to incorrect states.
These errors are allowed to occur as runtime errors instead of being prevented at compile time through stateful types. The alternative was tried, but was awkward to use in practice since async traits are not dyn compatible.
Variants