Enum Command

pub enum Command {
Show 20 variants DriverOutputControl = 1, BoosterSoftStartControl = 12, DeepSleepMode = 16, DataEntryModeSetting = 17, SwReset = 18, TemperatureSensorControl = 26, MasterActivation = 32, DisplayUpdateControl1 = 33, DisplayUpdateControl2 = 34, WriteRam = 36, WriteVcom = 44, WriteLut = 50, SetDummyLinePeriod = 58, SetGateLineWidth = 59, BorderWaveformControl = 60, SetRamXStartEnd = 68, SetRamYStartEnd = 69, SetRamX = 78, SetRamY = 79, Noop = 255,
}

Variants



DriverOutputControl = 1

Used to initialise the display.



BoosterSoftStartControl = 12

Used to configure the on chip voltage booster and regulator.



DeepSleepMode = 16

Used to enter deep sleep mode. Requires a hardware reset and reinitialisation to wake up.



DataEntryModeSetting = 17

Changes the auto-increment behaviour of the address counter.



SwReset = 18

Resets all commands and parameters to default values (except deep sleep mode).



TemperatureSensorControl = 26

Writes to the temperature register.



MasterActivation = 32

Activates the display update sequence. This must be set beforehand using [DisplayUpdateControl2]. This operation must not be interrupted.



DisplayUpdateControl1 = 33

Can be used to bypass the RAM content and directly read 1 or 0 for all pixels.



DisplayUpdateControl2 = 34

Configures the display update sequence for use with [MasterActivation].



WriteRam = 36

Writes data to RAM, autoincrementing the address counter.



WriteVcom = 44

Writes to the VCOM register.



WriteLut = 50

Writes the LUT register (30 bytes, exclude the VSH/VSL and dummy bits).



SetDummyLinePeriod = 58

? Part of magic config.



SetGateLineWidth = 59

? Part of magic config.



BorderWaveformControl = 60

Register to configure the behaviour of the border. This can be set directly to a fixed colour, or managed via the VCOM register.



SetRamXStartEnd = 68

Sets the start and end positions of the X axis.



SetRamYStartEnd = 69

Sets the start and end positions of the Y axis.



SetRamX = 78

Sets the current x coordinate of the address counter.



SetRamY = 79

Sets the current y coordinate of the address counter.



Noop = 255

Does nothing, but can be used to terminate other commands such as [WriteRam]