pub enum RefreshMode {
Full,
Partial,
PartialBlackBypass,
PartialWhiteBypass,
}Expand description
The refresh mode for the display.
Variants
Full
Use the full update LUT. This is slower, but should be done occasionally to avoid ghosting.
It’s recommended to avoid full refreshes less than RECOMMENDED_MIN_FULL_REFRESH_INTERVAL apart, but to do a full refresh at least every RECOMMENDED_MAX_FULL_REFRESH_INTERVAL.
Partial
Uses the partial update LUT for fast refresh. A full refresh should be done occasionally to avoid ghosting, see RECOMMENDED_MAX_FULL_REFRESH_INTERVAL.
This is the standard “fast” update. It diffs the current framebuffer against the previous framebuffer, and just updates the pixels that differ.
PartialBlackBypass
Uses the partial update LUT for a fast refresh, but only updates black (BinaryColor::Off)
pixels from the current framebuffer. The previous framebuffer is ignored.
PartialWhiteBypass
Uses the partial update LUT for a fast refresh, but only updates white (BinaryColor::On)
pixels from the current framebuffer. The previous framebuffer is ignored.
Implementations