pub enum RefreshMode {
Full,
Partial,
}Expand description
The refresh mode for the display.
Variants
Full
Use the full update LUT. This is slower, but should be done occasionally to avoid ghosting.
It’s recommended to avoid full refreshes less than RECOMMENDED_MIN_FULL_REFRESH_INTERVAL apart, but to do a full refresh at least every RECOMMENDED_MAX_FULL_REFRESH_INTERVAL.
Partial
Use the partial update LUT for fast refresh. A full refresh should be done occasionally to avoid ghosting, see RECOMMENDED_MAX_FULL_REFRESH_INTERVAL.
Implementations