pub enum Command {
Show 43 variants
PanelSet = 0,
PowerSet = 1,
PowerOff = 2,
PowerOffSequenceSet = 3,
PowerOn = 4,
PowerOnMeasure = 5,
BoosterSoftStart = 6,
DeepSleep = 7,
DisplayStartTrans1 = 16,
DataStop = 17,
DisplayRefresh = 18,
DisplayStartTrans2 = 19,
DualSPI = 21,
AutoSequence = 23,
KWLUTOption = 43,
PLLControl = 48,
TempSensorCalibration = 64,
TempSensorSelect = 65,
TempSensorWrite = 66,
TempSensorRead = 67,
PanelBreakCheck = 68,
VCOMDataInterval = 80,
LowerPowerDetection = 81,
EndVoltageSet = 82,
TCONSet = 96,
ResolutionSet = 97,
GateSourceStartSet = 101,
Revision = 112,
GetStatus = 113,
AutoMeasurementVCOM = 128,
ReadVCOM = 129,
VCOMDCSetting = 130,
PartialWindow = 144,
PartialIn = 145,
PartialOut = 146,
ProgramMode = 160,
ActiveProgramming = 161,
ReadOTP = 162,
CascadeSet = 224,
PowerSaving = 227,
LVDVoltageSelect = 228,
ForceTemperature = 229,
TempBoundaryPhaseC2 = 231,
}Expand description
Low-level commands for the Epd7in5 v2 display. You probably want to use the other methods exposed on the [Epd7in5] for most operations, but can send commands directly with [Epd7in5::send] for low-level control or experimentation.
Variants
PanelSet = 0
PowerSet = 1
PowerOff = 2
PowerOffSequenceSet = 3
PowerOn = 4
PowerOnMeasure = 5
BoosterSoftStart = 6
DeepSleep = 7
DisplayStartTrans1 = 16
DataStop = 17
DisplayRefresh = 18
DisplayStartTrans2 = 19
DualSPI = 21
AutoSequence = 23
KWLUTOption = 43
PLLControl = 48
TempSensorCalibration = 64
TempSensorSelect = 65
TempSensorWrite = 66
TempSensorRead = 67
PanelBreakCheck = 68
VCOMDataInterval = 80
LowerPowerDetection = 81
EndVoltageSet = 82
TCONSet = 96
ResolutionSet = 97
GateSourceStartSet = 101
Revision = 112
GetStatus = 113
AutoMeasurementVCOM = 128
ReadVCOM = 129
VCOMDCSetting = 130
PartialWindow = 144
PartialIn = 145
PartialOut = 146
ProgramMode = 160
ActiveProgramming = 161
ReadOTP = 162
CascadeSet = 224
PowerSaving = 227
LVDVoltageSelect = 228
ForceTemperature = 229
TempBoundaryPhaseC2 = 231