pub trait ErrorHw {
type Error;
}Expand description
Provides access to a shared error type.
Drivers rely on this trait to provide a single Error type that supports From conversions from all the hardware-specific error types.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".